package com.nasc.custom.service;

import com.nasc.custom.domain.NascVncDesktop;

import java.util.List;

/**
 * @Author: Yujianq
 * @Date: 2024/6/4 16:30
 * @Description: 远程桌面数据
 * @return:
 */
public interface INascVncDesktopService {

    /**
     * @Author: Yujianq
     * @Date: 2024/6/6 14:17
     * @Description: 根据条件分页查询远程桌面数据列表
     * @param vncDesktop
     * @return: java.util.List<com.nasc.custom.domain.NascVncDesktop>
     */
    public List<NascVncDesktop> selectVncDesktopList(NascVncDesktop vncDesktop);

    /**
     * @Author: Yujianq
     * @Date: 2024/6/6 14:30
     * @Description: 查询是否重复添加远程信息
     * @param vncDesktop
     * @return: java.lang.Long
     */
    public Long checkVncDesktopDuplicates(NascVncDesktop vncDesktop);

    /**
     * @Author: Yujianq
     * @Date: 2024/6/6 14:22
     * @Description: 保存远程桌面数据信息
     * @param vncDesktop
     * @return: int
     */
    public int insertVncDesktop(NascVncDesktop vncDesktop);

    /**
     * @Author: Yujianq
     * @Date: 2024/6/6 14:35
     * @Description: 修改远程桌面数据信息
     * @param vncDesktop
     * @return: int
     */
    public int updateVncDesktop(NascVncDesktop vncDesktop);

    /**
     * @Author: Yujianq
     * @Date: 2024/6/6 14:46
     * @Description: 批量根据ID进行删除远程桌面数据
     * @param ids
     * @return: int
     */
    public int deleteVncDesktopByIds(Long[] ids);

    /**
     * @Author: Yujianq
     * @Date: 2024/6/6 14:52
     * @Description: 根据ID查询远程桌面数据信息
     * @param id
     * @return: com.nasc.custom.domain.NascVncDesktop
     */
    public NascVncDesktop getVncDesktopInfo(Long id);

}
